# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.cli.core.commands.validators import get_default_location_from_resource_group


def load_arguments(self, _):

    with self.argument_context('hcs') as c:
        c.argument('location', validator=get_default_location_from_resource_group)

    with self.argument_context('hcs browse') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs create') as c:
        c.argument('name', help='A friendly human readable name for this Managed Application.')
        c.argument('email', help='This email will be used by HashiCorp to notify you about system updates and operational issues')
        c.argument('plan_name', help='Name of the billing plan you wish to use. Defaults to on-demand.')
        c.argument('location', help='Location. Valid Azure regions from: `az hcs list-regions` You can configure the default location using `az configure --defaults location=<location>`.')
        c.argument('consul_version', help='Consul Version. Valid versions from: `az hcs list-versions`.')
        c.argument('datacenter_name', help='Consul Datacenter Name. The datacenter name for this cluster. Default: dc1.')
        c.argument('external_endpoint', help='Should this cluster have an externally reachable HTTP and UI endpoint. Default: false.')
        c.argument('vnet_cidr', help='VNet Address space to use for this cluster. Default: 172.25.16.0/24')
        c.argument('federation_token', help='Federation token of a primary cluster. You can generate a token with: `az hcs create-federation-token`.')

    with self.argument_context('hcs create-token') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('output_kubernetes_secret', help='Output the token in yaml format for use in Kubernetes')

    with self.argument_context('hcs create-federation-token') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs show-federation') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs delete') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs generate-helm-values') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('aks_cluster_name', help='The name of the AKS cluster to generate config for.')
        c.argument('aks_resource_group', help='The resource group name where the AKS cluster is deployed if different from the Managed Application.')

    with self.argument_context('hcs generate-kubernetes-secret') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs get-config') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs update') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('consul_version', help='Consul version to update to. Format: `v1.8.0`.')

    with self.argument_context('hcs show') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs snapshot create') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('snapshot_name', help='Name of the snapshot.')

    with self.argument_context('hcs snapshot list') as c:
        c.argument('name', help='Name of the Managed Application.')

    with self.argument_context('hcs snapshot restore') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('snapshot', help='ID of the snapshot.')
        c.argument('take_snapshot', help='Take a snapshot before performing a restore. Default: false')

    with self.argument_context('hcs snapshot delete') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('snapshot', help='ID of the snapshot.')

    with self.argument_context('hcs snapshot rename') as c:
        c.argument('name', help='Name of the Managed Application.')
        c.argument('snapshot', help='ID of the snapshot.')
        c.argument('snapshot_name', help='Name of the snapshot to rename to.')
