# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

import os
import unittest

from azure.cli.testsdk import (ScenarioTest, ResourceGroupPreparer)


TEST_DIR = os.path.abspath(os.path.join(os.path.abspath(__file__), '..'))


class HcsScenarioTest(ScenarioTest):

    def current_subscription(self):
        subs = self.cmd('az account show').get_output_in_json()
        return subs['id']

    @ResourceGroupPreparer(random_name_length=20, name_prefix='cli-test-hcs-', key='rg')
    def test_hcs(self, resource_group):

        self.kwargs.update({
            'name': 'cli-test-hcs',
            'location': 'westus2',
            'subscription_id': self.current_subscription()
        })

        self.cmd('hcs create -g {rg} --name {name} -l {location}', checks=[
            self.check('name', '{name}'),
            self.check('provisioningState', 'Succeeded')
        ])
